@@ -1996,17 +1996,22 @@ PrivateAnimScreen::initiateCloseAnim (PrivateAnimWindow *aw)
 		getActualEffect (chosenEffect, AnimEventClose);
 
 	    // handle empty random effect list
-	    if (effectToBePlayed && effectToBePlayed == AnimEffectNone)
+	    if (effectToBePlayed)
 	    {
-		aw->mState = aw->mNewState;
-		return;
-	    }
+		if (effectToBePlayed == AnimEffectNone)
+		{
+		    aw->mState = aw->mNewState;
+		    return;
+		}
 
-	    aw->mCurAnimation =
-		effectToBePlayed->create (w, WindowEventClose, duration,
-					  effectToBePlayed, getIcon (w, true));
-	    aw->mCurAnimation->adjustPointerIconSize ();
-	    aw->enablePainting (true);
+		aw->mCurAnimation = effectToBePlayed->create (w,
+		                                              WindowEventClose,
+		                                              duration,
+		                                              effectToBePlayed,
+		                                              getIcon (w, true));
+		aw->mCurAnimation->adjustPointerIconSize ();
+		aw->enablePainting (true);
+	    }
 	}
 
 	activateEvent (true);
@@ -2902,7 +2907,8 @@ PrivateAnimWindow::PrivateAnimWindow (CompWindow *w,
     mDestroyCnt (0),
     mIgnoreDamage (false),
     mFinishingAnim (false),
-    mCurAnimSelectionRow (-1)
+    mCurAnimSelectionRow (-1),
+    mPrevAnimSelectionRow (-1)
 {
     mBB.x1 = mBB.y1 = MAXSHORT;
     mBB.x2 = mBB.y2 = MINSHORT;
