@@ -86,7 +86,7 @@ PrivateGLScreen::paintBackground (const GLMatrix   &transform,
     if (!nBox)
 	return;
 
-    if (screen->desktopWindowCount ())
+    if (screen->opaqueDesktopWindowCount ())
     {
 	if (!backgroundTextures.empty ())
 	{
@@ -1324,7 +1324,7 @@ GLWindow::glDraw (const GLMatrix     &transform,
 			      attrib, region, mask)
 
     const CompRegion &reg = (mask & PAINT_WINDOW_TRANSFORMED_MASK) ?
-                            infiniteRegion : region;
+                            CompRegion::infinite () : region;
 
     if (reg.isEmpty ())
 	return true;
