@@ -82,6 +82,7 @@ public:
     MOCK_METHOD1(_matchPropertyChanged, void (CompWindow *));
     MOCK_METHOD0(_outputChangeNotify, void ());
     MOCK_METHOD2(_cursorChangeNotify, void (const CompString&, int));
+    MOCK_METHOD1(_averageColorChangeNotify, void (const unsigned short*));
 
     MOCK_METHOD0(outputDevs, CompOutput::vector & ());
     MOCK_METHOD2(setWindowState, void (unsigned int state, Window id));
@@ -145,6 +146,7 @@ public:
 				CompSize   &size,
 				void       *&data));
     MOCK_METHOD0(desktopWindowCount, int ());
+    MOCK_METHOD0(opaqueDesktopWindowCount, int ());
     MOCK_METHOD0(attrib, XWindowAttributes ());
     MOCK_CONST_METHOD0(defaultIcon, CompIcon *());
     virtual bool otherGrabExist (const char *, ...) { return false; }  // TODO How to mock?
@@ -183,7 +185,9 @@ public:
     MOCK_METHOD0(snDisplay, SnDisplay * ());
     MOCK_CONST_METHOD0(createFailed, bool ());
     MOCK_METHOD0(incrementDesktopWindowCount, void ());
+    MOCK_METHOD0(incrementOpaqueDesktopWindowCount, void ());
     MOCK_METHOD0(decrementDesktopWindowCount, void ());
+    MOCK_METHOD0(decrementOpaqueDesktopWindowCount, void ());
     MOCK_METHOD0(nextMapNum, unsigned int ());
     MOCK_CONST_METHOD0(updatePassiveKeyGrabs, void ());
     MOCK_METHOD1(updatePassiveButtonGrabs, void (Window serverFrame));
@@ -196,6 +200,7 @@ public:
     MOCK_CONST_METHOD0(getTopServerWindow, CompWindow * ());
     MOCK_METHOD0(getCoreOptions, CoreOptions& ());
     MOCK_CONST_METHOD0(colormap, Colormap ());
+    MOCK_CONST_METHOD0(averageColor, const unsigned short * ());
     MOCK_METHOD1(setCurrentDesktop, void (unsigned int desktop));
     MOCK_CONST_METHOD0(activeWindow, Window ());
     MOCK_CONST_METHOD1(grabWindowIsNot, bool (Window w));
