@@ -197,8 +197,6 @@ namespace testing_values
     const std::string INACTIVE_SHADOW_COLOR_STR_VALUE ("#00000000");
     const gushort INACTIVE_SHADOW_COLOR_VALUE[] = { 0, 0, 0 };
     const gboolean USE_TOOLTIPS_VALUE = !USE_TOOLTIPS_DEFAULT;
-    const guint DRAGGABLE_BORDER_WIDTH_VALUE = 1;
-    const gboolean ATTACH_MODAL_DIALOGS_VALUE = TRUE;
     const std::string BLUR_TYPE_TITLEBAR_VALUE ("titlebar");
     const gint BLUR_TYPE_TITLEBAR_INT_VALUE = BLUR_TYPE_TITLEBAR;
     const std::string BLUR_TYPE_ALL_VALUE ("all");
@@ -243,7 +241,6 @@ class GWDSettingsTestCommon :
 	virtual void SetUp ()
 	{
 	    env.SetUpEnv ();
-	    g_type_init ();
 	}
 	virtual void TearDown ()
 	{
@@ -330,8 +327,6 @@ TEST_F(GWDMockSettingsWritableTest, TestMock)
 						       testing_values::INACTIVE_SHADOW_OFFSET_Y_VALUE,
 						       Eq (testing_values::INACTIVE_SHADOW_COLOR_STR_VALUE))).WillOnce (Return (TRUE));
     EXPECT_CALL (writableGMock, useTooltipsChanged (testing_values::USE_TOOLTIPS_VALUE)).WillOnce (Return (TRUE));
-    EXPECT_CALL (writableGMock, draggableBorderWidthChanged (testing_values::DRAGGABLE_BORDER_WIDTH_VALUE)).WillOnce (Return (TRUE));
-    EXPECT_CALL (writableGMock, attachModalDialogsChanged (testing_values::ATTACH_MODAL_DIALOGS_VALUE)).WillOnce (Return (TRUE));
     EXPECT_CALL (writableGMock, blurChanged (Eq (testing_values::BLUR_TYPE_TITLEBAR_VALUE))).WillOnce (Return (TRUE));
     EXPECT_CALL (writableGMock, metacityThemeChanged (TRUE, Eq (testing_values::METACITY_THEME_VALUE))).WillOnce (Return (TRUE));
     EXPECT_CALL (writableGMock, opacityChanged (testing_values::ACTIVE_OPACITY_VALUE,
@@ -364,8 +359,6 @@ TEST_F(GWDMockSettingsWritableTest, TestMock)
 								testing_values::INACTIVE_SHADOW_OFFSET_Y_VALUE,
 								testing_values::INACTIVE_SHADOW_COLOR_STR_VALUE.c_str ()), IsTrue ());
     EXPECT_THAT (gwd_settings_writable_use_tooltips_changed (writableMock.get (), testing_values::USE_TOOLTIPS_VALUE), IsTrue ());
-    EXPECT_THAT (gwd_settings_writable_draggable_border_width_changed (writableMock.get (), testing_values::DRAGGABLE_BORDER_WIDTH_VALUE), IsTrue ());
-    EXPECT_THAT (gwd_settings_writable_attach_modal_dialogs_changed (writableMock.get (), testing_values::ATTACH_MODAL_DIALOGS_VALUE), IsTrue ());
     EXPECT_THAT (gwd_settings_writable_blur_changed (writableMock.get (), testing_values::BLUR_TYPE_TITLEBAR_VALUE.c_str ()), IsTrue ());
     EXPECT_THAT (gwd_settings_writable_metacity_theme_changed (writableMock.get (),
 							       testing_values::USE_METACITY_THEME_VALUE,
@@ -465,22 +458,6 @@ TEST_F(GWDMockSettingsTest, TestMock)
 			   "use-tooltips",
 			   &booleanGValue);
 
-    EXPECT_CALL (settingsGMock, getProperty (GWD_MOCK_SETTINGS_PROPERTY_DRAGGABLE_BORDER_WIDTH,
-					     GValueMatch <gint> (0, g_value_get_int),
-					     _));
-
-    g_object_get_property (G_OBJECT (settingsMock.get ()),
-			   "draggable-border-width",
-			   &integerGValue);
-
-    EXPECT_CALL (settingsGMock, getProperty (GWD_MOCK_SETTINGS_PROPERTY_ATTACH_MODAL_DIALOGS,
-					     GValueMatch <gboolean> (FALSE, g_value_get_boolean),
-					     _));
-
-    g_object_get_property (G_OBJECT (settingsMock.get ()),
-			   "attach-modal-dialogs",
-			   &booleanGValue);
-
     EXPECT_CALL (settingsGMock, getProperty (GWD_MOCK_SETTINGS_PROPERTY_BLUR_CHANGED,
 					     GValueMatch <gint> (0, g_value_get_int),
 					     _));
@@ -761,52 +738,6 @@ TEST_F(GWDSettingsTest, TestUseTooltipsChangedIsDefault)
 							     USE_TOOLTIPS_DEFAULT), IsFalse ());
 }
 
-TEST_F(GWDSettingsTest, TestDraggableBorderWidthChanged)
-{
-    EXPECT_CALL (*mGMockNotified, updateDecorations ());
-    EXPECT_THAT (gwd_settings_writable_draggable_border_width_changed (GWD_SETTINGS_WRITABLE_INTERFACE (mSettings.get ()),
-								       testing_values::DRAGGABLE_BORDER_WIDTH_VALUE), IsTrue ());
-
-    AutoUnsetGValue draggableBorderWidthValue (G_TYPE_INT);
-    GValue &draggableBorderWidthGValue = draggableBorderWidthValue;
-
-    g_object_get_property (G_OBJECT (mSettings.get ()),
-			   "draggable-border-width",
-			   &draggableBorderWidthGValue);
-
-    EXPECT_THAT (&draggableBorderWidthGValue, GValueMatch <gint> (testing_values::DRAGGABLE_BORDER_WIDTH_VALUE,
-								  g_value_get_int));
-}
-
-TEST_F(GWDSettingsTest, TestDraggableBorderWidthChangedIsDefault)
-{
-    EXPECT_THAT (gwd_settings_writable_draggable_border_width_changed (GWD_SETTINGS_WRITABLE_INTERFACE (mSettings.get ()),
-								       DRAGGABLE_BORDER_WIDTH_DEFAULT), IsFalse ());
-}
-
-TEST_F(GWDSettingsTest, TestAttachModalDialogsChanged)
-{
-    EXPECT_CALL (*mGMockNotified, updateDecorations ());
-    EXPECT_THAT (gwd_settings_writable_attach_modal_dialogs_changed (GWD_SETTINGS_WRITABLE_INTERFACE (mSettings.get ()),
-								     testing_values::ATTACH_MODAL_DIALOGS_VALUE), IsTrue ());
-
-    AutoUnsetGValue attachModalDialogsValue (G_TYPE_BOOLEAN);
-    GValue &attachModalDialogsGValue = attachModalDialogsValue;
-
-    g_object_get_property (G_OBJECT (mSettings.get ()),
-			   "attach-modal-dialogs",
-			   &attachModalDialogsGValue);
-
-    EXPECT_THAT (&attachModalDialogsGValue, GValueMatch <gboolean> (testing_values::ATTACH_MODAL_DIALOGS_VALUE,
-								    g_value_get_boolean));
-}
-
-TEST_F(GWDSettingsTest, TestAttachModalDialogsChangedIsDefault)
-{
-    EXPECT_THAT (gwd_settings_writable_attach_modal_dialogs_changed (GWD_SETTINGS_WRITABLE_INTERFACE (mSettings.get ()),
-								     ATTACH_MODAL_DIALOGS_DEFAULT), IsFalse ());
-}
-
 TEST_F(GWDSettingsTest, TestBlurChangedTitlebar)
 {
     EXPECT_CALL (*mGMockNotified, updateDecorations ());
@@ -1218,8 +1149,6 @@ class GWDSettingsStorageFactoryWrapperInterface
 	virtual void SetUp (GWDSettingsWritable *writable) = 0;
 	virtual GWDSettingsStorage * GetStorage () = 0;
 	virtual void SetUseTooltips (gboolean useTooltips) = 0;
-	virtual void SetDraggableBorderWidth (gint draggableBorderWidth) = 0;
-	virtual void SetAttachModalDialogs (gboolean attachModalDialogs) = 0;
 	virtual void SetBlur (const std::string &blurType) = 0;
 	virtual void SetOpacity (gdouble activeOpacity,
 				 gdouble inactiveOpacity,
@@ -1283,26 +1212,6 @@ TEST_P (GWDSettingsTestStorageUpdates, TestSetUseTooltips)
     gwd_settings_storage_update_use_tooltips (storage);
 }
 
-TEST_P (GWDSettingsTestStorageUpdates, TestSetDraggableBorderWidth)
-{
-    GWDSettingsStorage *storage = GetParam ()->GetStorage ();
-    GetParam ()->SetDraggableBorderWidth (testing_values::DRAGGABLE_BORDER_WIDTH_VALUE);
-
-    EXPECT_CALL (*mSettingsMock, draggableBorderWidthChanged (testing_values::DRAGGABLE_BORDER_WIDTH_VALUE));
-
-    gwd_settings_storage_update_draggable_border_width (storage);
-}
-
-TEST_P (GWDSettingsTestStorageUpdates, TestSetAttachModalDialogs)
-{
-    GWDSettingsStorage *storage = GetParam ()->GetStorage ();
-    GetParam ()->SetAttachModalDialogs (testing_values::ATTACH_MODAL_DIALOGS_VALUE);
-
-    EXPECT_CALL (*mSettingsMock, attachModalDialogsChanged (testing_values::ATTACH_MODAL_DIALOGS_VALUE));
-
-    gwd_settings_storage_update_attach_modal_dialogs (storage);
-}
-
 TEST_P (GWDSettingsTestStorageUpdates, TestSetBlur)
 {
     GWDSettingsStorage *storage = GetParam ()->GetStorage ();
@@ -1406,24 +1315,6 @@ class GWDMockSettingsStorageFactoryWrapper :
 				gwd_settings_writable_use_tooltips_changed, mWritable, useTooltips)));
 	}
 
-	virtual void SetDraggableBorderWidth (gint draggableBorderWidth)
-	{
-	    EXPECT_CALL (*mStorageMock, updateDraggableBorderWidth ())
-		    .WillOnce (
-			InvokeFunctor (
-			    boost::bind (
-				gwd_settings_writable_draggable_border_width_changed, mWritable, draggableBorderWidth)));
-	}
-
-	virtual void SetAttachModalDialogs (gboolean attachModalDialogs)
-	{
-	    EXPECT_CALL (*mStorageMock, updateAttachModalDialogs ())
-		    .WillOnce (
-			InvokeFunctor (
-			    boost::bind (
-				gwd_settings_writable_attach_modal_dialogs_changed, mWritable, attachModalDialogs)));
-	}
-
 	virtual void SetBlur (const std::string &blurType)
 	{
 	    EXPECT_CALL (*mStorageMock, updateBlur ())
@@ -1536,8 +1427,9 @@ TEST_F (GWDSettingsStorageGSettingsTest, TestNoDeathOnConnectingSignalToNULLObje
 							      boost::bind (gwd_settings_storage_unref, _1));
 
     gwd_connect_org_compiz_gwd_settings (NULL, mStorage.get ());
-    gwd_connect_org_gnome_mutter_settings (NULL, mStorage.get ());
+    gwd_connect_org_gnome_metacity_settings (NULL, mStorage.get ());
     gwd_connect_org_gnome_desktop_wm_preferences_settings (NULL, mStorage.get ());
+    gwd_connect_org_mate_marco_general_settings (NULL, mStorage.get ());
 
     EXPECT_CALL (*mStorageMock, dispose ());
     EXPECT_CALL (*mStorageMock, finalize ());
@@ -1555,11 +1447,13 @@ class GWDSettingsStorageGSettingsFactoryWrapper :
 
 	    /* We do not need to keep a reference to these */
 	    mGWDSettings = gwd_get_org_compiz_gwd_settings ();
-	    mMutterSettings = gwd_get_org_gnome_mutter_settings ();
+	    mMetacitySettings = gwd_get_org_gnome_metacity_settings ();
 	    mDesktopSettings = gwd_get_org_gnome_desktop_wm_preferences_settings ();
+	    mMarcoSettings = gwd_get_org_mate_marco_general_settings ();
 
 	    mStorage.reset (gwd_settings_storage_gsettings_new (mDesktopSettings,
-								mMutterSettings,
+								mMetacitySettings,
+								mMarcoSettings,
 								mGWDSettings,
 								writable),
 			    boost::bind (gwd_settings_storage_unref, _1));
@@ -1575,16 +1469,6 @@ class GWDSettingsStorageGSettingsFactoryWrapper :
 	    g_settings_set_boolean (mGWDSettings, ORG_COMPIZ_GWD_KEY_USE_TOOLTIPS, useTooltips);
 	}
 
-	virtual void SetDraggableBorderWidth (gint draggableBorderWidth)
-	{
-	    g_settings_set_int (mMutterSettings, ORG_GNOME_MUTTER_DRAGGABLE_BORDER_WIDTH, draggableBorderWidth);
-	}
-
-	virtual void SetAttachModalDialogs (gboolean attachModalDialogs)
-	{
-	    g_settings_set_boolean (mMutterSettings, ORG_GNOME_MUTTER_ATTACH_MODAL_DIALOGS, attachModalDialogs);
-	}
-
 	virtual void SetBlur (const std::string &blurType)
 	{
 	    g_settings_set_string (mGWDSettings, ORG_COMPIZ_GWD_KEY_BLUR_TYPE, blurType.c_str ());
@@ -1606,6 +1490,7 @@ class GWDSettingsStorageGSettingsFactoryWrapper :
 	{
 	    g_settings_set_boolean (mGWDSettings, ORG_COMPIZ_GWD_KEY_USE_METACITY_THEME, useMetacityTheme);
 	    g_settings_set_string (mDesktopSettings, ORG_GNOME_DESKTOP_WM_PREFERENCES_THEME, metacityTheme.c_str ());
+	    g_settings_set_string (mMarcoSettings, ORG_MATE_MARCO_GENERAL_THEME, metacityTheme.c_str ());
 	}
 
 	virtual void SetButtonLayout (const std::string &buttonLayout)
@@ -1613,6 +1498,9 @@ class GWDSettingsStorageGSettingsFactoryWrapper :
 	    g_settings_set_string (mDesktopSettings,
 				   ORG_GNOME_DESKTOP_WM_PREFERENCES_BUTTON_LAYOUT,
 				   buttonLayout.c_str ());
+	    g_settings_set_string (mMarcoSettings,
+				   ORG_MATE_MARCO_GENERAL_BUTTON_LAYOUT,
+				   buttonLayout.c_str ());
 	}
 
 	virtual void SetFont (gboolean useSystemFont, const std::string &titlebarFont)
@@ -1623,6 +1511,12 @@ class GWDSettingsStorageGSettingsFactoryWrapper :
 	    g_settings_set_string (mDesktopSettings,
 				   ORG_GNOME_DESKTOP_WM_PREFERENCES_TITLEBAR_FONT,
 				   titlebarFont.c_str ());
+	    g_settings_set_boolean (mMarcoSettings,
+				    ORG_MATE_MARCO_GENERAL_TITLEBAR_USES_SYSTEM_FONT,
+				    useSystemFont);
+	    g_settings_set_string (mMarcoSettings,
+				   ORG_MATE_MARCO_GENERAL_TITLEBAR_FONT,
+				   titlebarFont.c_str ());
 	}
 
 	virtual void SetTitlebarActions (const std::string &doubleClickAction,
@@ -1647,6 +1541,15 @@ class GWDSettingsStorageGSettingsFactoryWrapper :
 	    g_settings_set_string (mDesktopSettings,
 				   ORG_GNOME_DESKTOP_WM_PREFERENCES_ACTION_RIGHT_CLICK_TITLEBAR,
 				   translatedRC.c_str ());
+	    g_settings_set_string (mMarcoSettings,
+				   ORG_MATE_MARCO_GENERAL_ACTION_DOUBLE_CLICK_TITLEBAR,
+				   translatedDC.c_str ());
+	    g_settings_set_string (mMarcoSettings,
+				   ORG_MATE_MARCO_GENERAL_ACTION_MIDDLE_CLICK_TITLEBAR,
+				   translatedMC.c_str ());
+	    g_settings_set_string (mMarcoSettings,
+				   ORG_MATE_MARCO_GENERAL_ACTION_RIGHT_CLICK_TITLEBAR,
+				   translatedRC.c_str ());
 	    g_settings_set_string (mGWDSettings,
 				   ORG_COMPIZ_GWD_KEY_MOUSE_WHEEL_ACTION,
 				   mouseWheelAction.c_str ());
@@ -1656,8 +1559,9 @@ class GWDSettingsStorageGSettingsFactoryWrapper :
 	{
 	    mStorage.reset ();
 	    mGWDSettings = NULL;
-	    mMutterSettings = NULL;
+	    mMetacitySettings = NULL;
 	    mDesktopSettings = NULL;
+	    mMarcoSettings = NULL;
 	    gsettingsEnv.TearDownEnv ();
 	    gsliceEnv.TearDownEnv ();
 	}
@@ -1665,8 +1569,9 @@ class GWDSettingsStorageGSettingsFactoryWrapper :
     private:
 
 	GSettings			       *mGWDSettings;
-	GSettings			       *mMutterSettings;
+	GSettings			       *mMetacitySettings;
 	GSettings			       *mDesktopSettings;
+	GSettings			       *mMarcoSettings;
 	boost::shared_ptr <GWDSettingsStorage> mStorage;
 	CompizGLibGSliceOffEnv                 gsliceEnv;
 	CompizGLibGSettingsMemoryBackendTestingEnv gsettingsEnv;
